@@ -1,5 +1,4 @@
 from .types import t_asset, copy_button, t_add, t_update, t_delete
-from .runner.env_var import n_env
 from .manager import Manager
 import os
 
@@ -36,12 +35,7 @@ class Assets:
                 kind = None
                 if item["type"] == self.role and item["status"] != t_delete:
                     kind = f"gettable with this url {self.manager.proxy_url('assets', item['value'])}"
-                    path = (
-                        item["path"]
-                        .replace(n_env.path_naas_folder, "")
-                        .replace(n_env.server_root, "")
-                    )
-                    print(f"File ==> {path} is {kind}")
+                    print(f'File ==> {item["path"]} is {kind}')
 
     def find(self, path=None):
         current_file = self.manager.get_path(path)
