@@ -1,5 +1,4 @@
 from .types import t_dependency, t_add, t_update, t_delete
-from .runner.env_var import n_env
 from .manager import Manager
 
 
@@ -33,12 +32,7 @@ class Dependency:
         else:
             for item in json_data:
                 if item["type"] == self.role and item["status"] != t_delete:
-                    path = (
-                        item["path"]
-                        .replace(n_env.path_naas_folder, "")
-                        .replace(n_env.server_root, "")
-                    )
-                    print(f"File ==> {path}")
+                    print(f'File ==> {item["path"]}')
 
     def add(self, path=None, debug=False):
         if self.manager.is_production():
